@@ -48,14 +48,14 @@ sub channel_history_menu {
         }
         elsif ( $choice eq $channel ) {
             my ( $sticky,  $sticky_url )  = _sticky_name_and_url( $opt->{channel_sticky} );
-            my ( $history, $history_url, $last ) = _history_name_and_url( $opt, $opt->{channel_history} );
+            my ( $history, $history_url, $removed_next ) = _history_name_and_url( $opt, $opt->{channel_history} );
             my $prompt = 'Channels:' . "\n";
             my @ids;
 
             CHANNEL: while ( 1 ) {
                 my $confirm = '  CONFIRM';
                 my @pre = ( undef, $confirm );
-                my $choices = _channel_choices( \@pre, $sticky, $history, $last );
+                my $choices = _channel_choices( \@pre, $sticky, $history, $removed_next );
                 # Choose
                 my @indexes = choose(
                     $choices,
@@ -86,7 +86,7 @@ sub channel_history_menu {
                             $prompt .= sprintf "= %s (%s)\n", $history->[$i], $opt->{channel_history}{$history_url->[$i]}{channel_id};
                         }
                     }
-                    $opt->{nr_of_latest_videos} = $list_size[$list_size_idx] =~ /\D(\d+)/ ? $1 : 0;
+                    $opt->{max_videos} = $list_size[$list_size_idx] =~ /\D(\d+)/ ? $1 : 0;
                     return @ids;
                 }
                 else {
@@ -109,6 +109,7 @@ sub channel_history_menu {
             my ( $sticky,  $sticky_url )  = _sticky_name_and_url( $opt->{channel_sticky} );
             my ( $history, $history_url ) = _history_name_and_url( $opt, $opt->{channel_history} );
             my $changed = 0;
+
             STICKY: while ( 1 ) {
                 my @pre = ( undef );
                 my $idx = choose(
@@ -150,11 +151,11 @@ sub channel_history_menu {
 
 
 sub _channel_choices {
-    my ( $pre, $sticky, $history, $last ) = @_;
+    my ( $pre, $sticky, $history, $removed_next ) = @_;
     my $choices = [ @$pre, map( "* $_", @$sticky ) ];
     for my $i ( 0 .. $#$history ) {
-            push @$choices, "  $history->[$i]" if ! $last->[$i];
-            push @$choices, "| $history->[$i]" if   $last->[$i];
+        push @$choices, "  $history->[$i]" if ! $removed_next->[$i];
+        push @$choices, "| $history->[$i]" if   $removed_next->[$i];
     }
     return $choices;
 }
@@ -164,30 +165,30 @@ sub _history_name_and_url {
     my ( $opt, $ref ) = @_;
     my $tmp_name = [];
     my $tmp_url  = [];
-    my $tmp_last = [];
+    my $tmp_removed_next = [];
     my $count = 0;
     for my $key ( sort { $ref->{$b}{timestamp} <=> $ref->{$a}{timestamp} } keys %$ref ) {
         $count++;
         push @$tmp_name, $ref->{$key}{channel};
         push @$tmp_url, $key;
-        push @$tmp_last, $count >= $opt->{max_channels} ? 1 : 0;
+        push @$tmp_removed_next, $count >= $opt->{max_channels} ? 1 : 0;
     }
     my $history_name = [];
     my $history_url  = [];
-    my $history_last = [];
+    my $removed_next = [];
     if ( ! $opt->{channel_by_timestamp} ) {
         for my $i ( sort { lc $tmp_name->[$a] cmp lc $tmp_name->[$b] } 0 .. $#$tmp_name ) {
             push @$history_name, $tmp_name->[$i];
             push @$history_url,  $tmp_url->[$i];
-            push @$history_last, $tmp_last->[$i];
+            push @$removed_next, $tmp_removed_next->[$i];
         }
     }
     else {
         $history_name = $tmp_name;
         $history_url  = $tmp_url;
-        $history_last = $tmp_last;
+        $removed_next = $tmp_removed_next;
     }
-    return $history_name, $history_url, $history_last;
+    return $history_name, $history_url, $removed_next;
 }
 
 
@@ -204,22 +205,21 @@ sub _sticky_name_and_url {
 
 
 sub add_channel_to_history {
-    my ( $opt, $info, $video_id ) = @_;
-    my $channel       = $info->{$video_id}{uploader};
-    my $channel_id    = $info->{$video_id}{uploader_id};
-    my $extractor_key = $info->{$video_id}{extractor_key};
+    my ( $opt, $info, $ex, $video_id ) = @_;
+    my $channel    = $info->{$ex}{$video_id}{uploader};
+    my $channel_id = $info->{$ex}{$video_id}{uploader_id};
+    return if ! length $channel_id;
     my $channel_url;
-    $channel_url = 'c#'                if $info->{$video_id}{extractor_key} eq 'Youtube';
-    $channel_url = 'http://vimeo.com/' if $info->{$video_id}{extractor_key} eq 'Vimeo';
+    $channel_url = 'c#'                if $ex eq 'youtube';
+    $channel_url = 'http://vimeo.com/' if $ex eq 'vimeo'; #
     if ( defined $channel_url ) {
         $channel_url .= $channel_id;
         if ( none{ $channel_url eq $_ } keys %{$opt->{channel_sticky}} ) {
             $opt->{channel_history}{$channel_url} = {
-                channel_url   => $channel_url,
-                channel       => $channel,
-                channel_id    => $channel_id,
-                extractor_key => $extractor_key,
-                timestamp     => time(),
+                channel     => $channel,
+                channel_id  => $channel_id,
+                extractor   => $ex,
+                timestamp   => time(),
             };
         }
     }
